@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 
 import os
@@ -13,16 +12,26 @@ import flask_limiter
 from theme_config import *
 
 description = "Flask-Limiter provides rate limiting features to flask applications."
-copyright = "2021, Ali-Akber Saifee"
+copyright = "2022, Ali-Akber Saifee"
 project = "Flask-Limiter"
 
-release, part = flask_limiter.__version__.split("+")
-version = flask_limiter.__version__
+ahead = 0
+
+if ".post0.dev" in flask_limiter.__version__:
+    version, ahead = flask_limiter.__version__.split(".post0.dev")
+else:
+    version = flask_limiter.__version__
+
+release = version
+
 html_title = f"{project} <small><b style='color: var(--color-brand-primary)'>{{{release}}}</b></small>"
 try:
-    ahead = int(part.rsplit(".")[0])
+    ahead = int(ahead)
+
     if ahead > 0:
-        html_theme_options["announcement"] = f"""
+        html_theme_options[
+            "announcement"
+        ] = f"""
         This is a development version. The documentation for the latest version: <b>{release}</b> can be found <a href="/en/stable">here</a>
         """
         html_title = f"{project} <small><b style='color: var(--color-brand-primary)'>{{dev}}</b></small>"
@@ -40,15 +49,17 @@ html_css_files = [
 html_theme_options.update({"light_logo": "tap-icon.png", "dark_logo": "tap-icon.png"})
 
 extensions = [
-    "alabaster",
+    "enum_tools.autoenum",
     "sphinx.ext.autodoc",
     "sphinx.ext.autosectionlabel",
     "sphinx.ext.autosummary",
     "sphinx.ext.extlinks",
     "sphinx.ext.intersphinx",
+    "sphinxext.opengraph",
     "sphinx.ext.todo",
     "sphinx.ext.viewcode",
     "sphinxcontrib.programoutput",
+    "sphinx_issues",
     "sphinx_panels",
     "sphinx_paramlinks",
 ]
@@ -62,8 +73,12 @@ autodoc_default_options = {
 add_module_names = False
 autoclass_content = "both"
 autodoc_typehints_format = "short"
+autodoc_preserve_defaults = True
 autosectionlabel_maxdepth = 3
 autosectionlabel_prefix_document = True
+issues_github_path = "alisaifee/flask-limiter"
+
+ogp_image = "_static/logo.png"
 
 extlinks = {
     "pypi": ("https://pypi.org/project/%s", "%s"),
